
*file contains code for analyses in paper “Saving and Portfolio Allocation Before and After Job Loss”. For questions faa@ssb.no

clear all

*set path with datasets
cd $data_folder

/*
datasets:
final_sample_u_ds.dta - main sample of job losers used in most analyses
control2013.dta - sample of non-job losers, used in artificial job loss robustness
final_sample_u_ds_rr2014_female - file containing also female job losses derived in same fashion as in final_sample_u_ds.dta
*/


u final_sample_u_ds.dta, replace

*create age poly
gen age2 = age*age
gen age3 = age*age*age
gen age4 = age2*age2

*****
*****Making tables
*****
ren ry5 RY1
ren ry6 RY2
ren ry7 RY3
ren ry8 RY4
ren ry9 RY5
ren ry10 RY6
ren ry11 RY7
ren ry12 RY8
ren ry13 RY9

*the variable rel_year is the a categorical variable around job loss, ranging from -8 to + 8, where 0 is the year of job loss

gen REL = rel_year 
replace REL = REL + 100 if rel_year <5 & rel_year > -5
replace REL = 0 if REL < 90

******
******Table 3, Figures 1 - 4
******

eststo clear
areg income_m i.REL d1995-d2003 d2005-d2007 age age2 age3 age4, cluster(famnr) absorb(famnr)
margins REL, atmeans post
eststo 
 
areg finw i.REL d1995-d2003 d2005-d2007 age age2 age3 age4, cluster(famnr) absorb(famnr)
margins REL, atmeans post
eststo 
 
areg safe i.REL d1995-d2003 d2005-d2007 age age2 age3 age4, cluster(famnr) absorb(famnr)
margins REL, atmeans post
eststo 
 
areg risk i.REL d1995-d2003 d2005-d2007 age age2 age3 age4, cluster(famnr) absorb(famnr)
margins REL, atmeans post
eststo 


esttab, se nostar noparentheses nogap, csv


******
******Table 4, Figures 7 - 10
******Mass Layoff, ds_det indicates downsizing of 30% or more


eststo clear
areg income_m i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if ds_det>=0.3, cluster(famnr) absorb(famnr)
margins REL, atmeans post
eststo 
 
areg finw i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if ds_det>=0.3, cluster(famnr) absorb(famnr)
margins REL, atmeans post
eststo 
 
areg safe i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if  ds_det>=0.3, cluster(famnr) absorb(famnr)
margins REL, atmeans post
eststo 
 
areg risk i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if  ds_det>=0.3, cluster(famnr)  absorb(famnr)
margins REL, atmeans post
eststo 


esttab, se nostar noparentheses nogap



******
******Figure 11, inverse hyperbolic sine function
******

*Create permanent income proxy, take mean of deflated values prior to job loss
gen inc_p0 = inc_m if rel == -4 | rel == -3 | rel == -2
bysort famnr (inc_p): egen inc_p = mean(inc_p0)

global jobloss income_m finw safe risk

foreach var of varlist $jobloss {
	gen `var'_perm = `var'/inc_p
	gen ihs_`var'_perm = ln(`var'_perm + sqrt(`var'_perm^2+1 ) )
	}


foreach var of varlist $jobloss {
areg ihs_`var'_perm i.REL d1995-d2003 d2005-d2007 age age2 age3  age4, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo 
				}
esttab , nogaps csv nostar not

******
******Figure 12, alternative wealth measures, and A.8
******

gen nw = 4*realest_h + finw -debt_h + voluntary

gen gfinw = finw - debt_h

foreach var of gfinw nw debt_h {
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
*those that do not move
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if REDM == 13, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
				}
esttab , nogaps csv nostar not



*****
*****Table 2, Wealth distribution
*****


keep if rel == -4
tabstat finw risk safe debt_h nw , statistics(p10 p25 median p75 p90) 
latabstat finw risk safe debt_h nw if rel == -4, statistics(p5 p25 median p75 p95) tf(SummaryWealth) replace f(%9.0f)
su rsD debt_h nw, det

*****
*****Figure A.1, split by initial home ownership
*****
gen hoD = reD if rel == -4
bysort famnr (hoD): replace hoD = hoD[1]

eststo clear
foreach var of varlist $jobloss {
atreg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
atreg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
				}
esttab , nogaps csv nostar not

*****
*****Figure A.2, split by education
*****

bysort famnr: egen educ_top = max(educ)

g educ_l = 1 if educ_top < 4
replace educ_l = 2 if educ_top == 4 | educ_top== 5  
replace educ_l = 3 if educ_top >5 & educ_top < 9	

eststo clear
foreach var of varlist $jobloss {
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if educ_l == 1, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if educ_l == 2, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if educ_l == 3, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
				}
esttab , nogaps csv nostar not

*****
*****Figure A.3, single vs dual owner
*****

gen dual = 1 if income_f > grunnbelop  & (rel == -4 | rel == -3)	
bysort famnr (dual): replace dual = dual[1]
replace dual = 0 if dual == . 

eststo clear
foreach var of varlist $jobloss {
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if dual == 1, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3  age4 if dual == 0, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
				}

esttab , nogaps csv nostar not


*****
*****Figure A.4, sample split by wealth to income quartiles
*****

gen wti = finw_perm if rel == -4
bysort famnr: egen wti2 = max(wti)
xtile wtiq = wti2, nquantiles(4)


eststo clear
foreach var of varlist $jobloss {
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if wtiq < 3, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if wtiq > 2, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if wtiq == 1, absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if wtiq == 2,  absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if wtiq == 3,  absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if wtiq == 4,  absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
				}

esttab , nogaps csv nostar not



*****
*****Figure A.5, by starting with initial risk
*****

gen risk_start = rsD  if rel == -4
bysort famnr: egen risk_start2 = max(risk_start)

eststo clear
foreach var of varlist $jobloss {
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if risk_start2 == 0,   absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if risk_start2 == 1,   absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
				}

esttab , nogaps csv nostar not

*****
*****Figure A.6, Added Worker Effect
*****


eststo clear
areg income_f i.REL d1995-d2003 d2005-d2007  age age2 age3 age4 ,  absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
esttab , nogaps csv nostar not


*****
*****Figure A.7, Female jobloss vs male. Need to have a file where also females lose their job. 
*****

preserve

u final_sample_u_ds_rr2014_female, replace

tab rel, g(ry)
tab year, g(d)
gen age2 = age*age
gen age3 = age*age*age
gen age4 = age2*age2

global jobloss_f income_m income_f finw safe risk

eststo clear
foreach var of varlist $jobloss_f {
areg `var' i.REL d1-d9 d11-d13 age age2 age3 age4,   absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1-d9 d11-d13 if femaleU == 1,   absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
areg `var' i.REL d1-d9 d11-d13 if maleU == 1,   absorb(famnr) cluster(famnr)
margins REL, atmeans post
eststo
				}
esttab , nogaps csv nostar not

*return to male data set
restore


*****
*****Figure A.9, Separate workers who find and who do not find new work
*****

forvalues i = 1/4 {
	gen u`i' = u_mD if rel == `i'
	bysort fnr (u`i') : replace u`i' = u`i'[1]
	}

gen reE = 1 if u2 == 0 & u3 == 0 & u4 == 0
replace reE = 0 if u1 == 1 & u2 == 1 & u3 == 1

gen rel2 = rel if reE != .
tab rel2, g(ry_)

gen ry10E = ry_10 if reE == 1 & u1 == 0
replace ry10E = 0 if ry10E == . & reE != .
gen ry11E = ry_11 if reE == 1
replace ry11E = 0 if reE == 0 
gen ry12E = ry_12 if reE == 1
replace ry12E = 0 if reE == 0
gen ry13E = ry_13 if reE == 1
replace ry13E = 0 if reE == 0

eststo clear
areg income_m ry5-ry13 d1995-d2003 d2005-d2007  age age2 age3 age4if reE != .,   absorb(famnr) cluster(famnr)
eststo 
areg income_m ry5-ry13 ry10E ry11E ry12E ry13E reE d1995-d2003 d2005-d2007  age age2 age3 age4,   absorb(famnr) cluster(famnr)
eststo
areg finw ry5-ry13 d1995-d2003 d2005-d2007  age age2 age3 age4if reE != .,   absorb(famnr) cluster(famnr)
eststo 
areg finw ry5-ry13 ry10E ry11E ry12E ry13E d1995-d2003 d2005-d2007  age age2 age3 age4,   absorb(famnr) cluster(famnr)
eststo
areg safe ry5-ry13 d1995-d2003 d2005-d2007  age age2 age3 age4 if reE != .,   absorb(famnr) cluster(famnr)
eststo 
areg safe ry5-ry13 ry10E ry11E ry12E ry13E d1995-d2003 d2005-d2007  age age2 age3 age4,   absorb(famnr) cluster(famnr)
eststo
areg risk ry5-ry13 d1995-d2003 d2005-d2007  age age2 age3 age4 if reE != .,   absorb(famnr) cluster(famnr)
eststo 
areg risk ry5-ry13 ry10E ry11E ry12E ry13E d1995-d2003 d2005-d2007 age age2 age3 age4 ,   absorb(famnr) cluster(famnr)
eststo

esttab , nogaps csv nostar not


*****
*****Figure 5, Household Risky Shares
*****

areg rs i.REL d1995-d2003 d2005-d2007 age age2 age3 age4,   absorb(famnr) cluster(famnr)
eststo
areg rs i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if rsD == 1,  absorb(famnr) cluster(famnr)
eststo
areg rs i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if risk_start2 == 1,  absorb(famnr) cluster(famnr)
eststo
rifreg rs i.REL d1995-d2003 d2005-d2007 age age2 age3 age4 if risk_start2 == 1, quantile(50)
eststo

esttab , nogaps csv nostar not


*****
*****Figure 6, artificial job loss sample
*****

*need to load sample of control households who do not lose job>
u control2013.dta if year == 1995

*generate random year of “jobloss”
g noise = uniform()
g ref = 1999 if noise <= 0.2
replace ref = 2000 if noise >0.2
replace ref = 2001 if noise >0.4
replace ref = 2002 if noise >0.6
replace ref = 2003 if noise >0.8

keep famnr ref
merge 1:m famnr using control2013

*generate referance and relative years
g rel_year= year-ref
tabulate rel_year, gen(ry)

*add in unemployment sample
append using final_sample_u_ds

*main sample = 1 
g ms = control == 0

forvalues i = 5/13 {
	gen msry`i' = ms*ry`i'
	}

forvalues i = 1995/2007 {
	gen msd`i' = ms*d`i'
	}

g age2 = age*age
g age3= age2*age
g age4= age2*age2

eststo clear
areg income_m ry5-ry13 msry5-msry13 ms d1995-d2003 d2005-d2007  msd1995-msd2003 msd2005-msd2007 age age2  age3 age4, absorb(famnr) cluster(famnr)
eststo
areg finw ry5-ry13 msry5-msry13 ms d1995-d2003 d2005-d2007  msd1995-msd2003 msd2005-msd2007 age age2 age3 age4, absorb(famnr) cluster(famnr)
eststo 
areg safe ry5-ry13 msry5-msry13 ms d1995-d2003 d2005-d2007  msd1995-msd2003 msd2005-msd2007 age age2  age3 age4, absorb(famnr) cluster(famnr)
eststo 
areg risk ry5-ry13 msry5-msry13 ms d1995-d2003 d2005-d2007  msd1995-msd2003 msd2005-msd2007 age age2  age3 age4, absorb(famnr) cluster(famnr)
eststo
esttab , csv drop(d* msd*) not nostar nogap




